package SomeClass;

use Object::Tiny::Lvalue qw( foo bar );

1;
